# Notification config

The dataclasses that represent a Notification configuration.
The first one is for the main process, the second one is for the actual creation & waiting for callback process.

::: mac_notifications.notification_config.NotificationConfig

::: mac_notifications.notification_config.JSONNotificationConfig
